<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+111"/>
      <source>Reverse Engineering</source>
      <translation>Visszatervezés</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>Hozzávetőleges sík ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>Sík megbecsülése</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-62"/>
      <source>Reverse Engineering</source>
      <translation>Visszatervezés</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate surface...</source>
      <translation>Hozzávetőleges felület...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-Spline surface</source>
      <translation>Hozzávetőleges B-Spline felület</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation>Visszatervezés</translation>
    </message>
  </context>
</TS>
